@@ -4,19 +4,10 @@ use std::ops::Range;
 
 use bitflags::bitflags;
 
-use crate::geometry::{
-    self,
-    Bounds,
-    Transform2D,
-};
+use crate::geometry::{self, Bounds, Transform2D};
 use crate::renderer::Vertex;
 use crate::utils::VecRetainMut;
-use crate::{
-    FillRule,
-    LineCap,
-    LineJoin,
-    Solidity,
-};
+use crate::{FillRule, LineCap, LineJoin, Solidity};
 
 use super::Verb;
 
@@ -228,7 +219,7 @@ impl PathCache {
         let all_points = &mut cache.points;
         let bounds = &mut cache.bounds;
 
-        cache.contours.retain_mut(|contour| {
+        VecRetainMut::retain_mut(&mut cache.contours, |contour| {
             let mut points = &mut all_points[contour.point_range.clone()];
 
             // If the first and last points are the same, remove the last, mark as closed contour.
